Skip to contents

Produces a faceted panel with colony area (mm\(^2\)) on one facet and radial growth rate (mm/day) on the other. When each plate appears only once in the data, points from all plates are connected in day order.

Usage

plot_radial_growth_area(x)

Arguments

x

A grayleafspot_run object or data accepted by as_grayleafspot_growth_data().

Value

A ggplot2 object.