Skip to contents

Reads the radialProfile field from raw_results. When called with a plain data frame, the function auto-discovers the most recent analysis.json under outputs/ in the working directory.

Usage

plot_radial_profile(x)

Arguments

x

A grayleafspot_run object, a path to a run directory or analysis.json, a list of raw results, or a data frame.

Value

A ggplot2 object.