Plots eccentricity against crack coverage percentage, with point size proportional to colony diameter and colour encoding time (day).
Arguments
- x
A
grayleafspot_runobject or data accepted byas_grayleafspot_growth_data().
Plots eccentricity against crack coverage percentage, with point size proportional to colony diameter and colour encoding time (day).
A grayleafspot_run object or data accepted by
as_grayleafspot_growth_data().